Module parse

Module parse 

Available on crate feature http_support only.

Structs

BodyReader
Http body reader created by http parsers, see mod parse for more information.
Config
Http packet parse config.
Requester
Http request packet parser.
Responser
Http response packet parser.

Enums

ParseError

Functions

parse_request
Helper function to help parsing stream into Request instance.
parse_request_with
Helper function to help parsing stream into Request instance.
parse_response
Helper function to help parsing stream into Response instance.
parse_response_with
Helper function to help parsing stream into Response instance.

Type Aliases

ParseResult
Type alias for parser result.