pub struct BodyReader<S> { /* private fields */ }Available on crate feature
http_support only.Expand description
Http body reader created by http parsers, see mod parse for more information.
Implementations
Sourceimpl<S> BodyReader<S>
impl<S> BodyReader<S>
Sourceimpl<S> BodyReader<S>
impl<S> BodyReader<S>
Sourcepub async fn into_bytes(
self,
max_body_len: usize,
timeout: Option<Duration>,
) -> ParseResult<BytesMut>
pub async fn into_bytes( self, max_body_len: usize, timeout: Option<Duration>, ) -> ParseResult<BytesMut>
Consume BodyReader into BytesMut.
Use max_body_len to limit memory buf usage, which may be useful for server-side code.
Sourcepub async fn from_json<T>(self, timeout: Option<Duration>) -> ParseResult<T>where
for<'a> T: Deserialize<'a>,
pub async fn from_json<T>(self, timeout: Option<Duration>) -> ParseResult<T>where
for<'a> T: Deserialize<'a>,
Deserialize an instance of type T from http json format body.
The maximum body length is limited to 4096 bytes,
use from_json_with instead if you want to use other values.
Sourcepub async fn from_json_with<T>(
self,
max_body_len: usize,
timeout: Option<Duration>,
) -> ParseResult<T>where
for<'a> T: Deserialize<'a>,
pub async fn from_json_with<T>(
self,
max_body_len: usize,
timeout: Option<Duration>,
) -> ParseResult<T>where
for<'a> T: Deserialize<'a>,
Deserialize an instance of type T from http json format body.
Use max_body_len to limit memory buf usage, which may be useful for server-side code.