Module server

Module server 

Available on crate feature http_support only.
Utilities for http server-side program.

Structs

HttpServer
The http server builder.
HttpSslServer
The https server configuration builder, which contains a http server configuration within.

Functions

serve
Parse the incoming http request via the read and then, call the handler to process the request.