HttpServer

Struct HttpServer 

pub struct HttpServer { /* private fields */ }
Available on crate feature http_support only.
The http server builder.

Implementations

Source

impl HttpServer

pub fn bind<A: ToSocketAddrs>(laddrs: A) -> Self

Create new http server builder with local binding addresses.

pub fn on(listener: TcpListener) -> Self

Create new http server builder with external TcpListener.

pub fn with_timeout(self, duration: Duration) -> Self

Set the reading timeout duration for newly incoming http request.

The default value is 30s.

pub fn with_ssl(self, ssl_acceptor: SslAcceptor) -> HttpSslServer

Convert HttpServer into HttpSslServer with provided ssl_acceptor

pub async fn create(self) -> Result<(TcpListener, Duration)>

Consume self and create http server listener

On success, returns created listener and the reading timeout duration.

pub async fn serve<H, Fut>(self, handler: H) -> Result<()>
where H: FnMut(Request<BodyReader<TcpStreamRead>>, ResponseWriter<TcpStreamWrite>) -> Fut + Send + Sync + Clone + 'static, Fut: Future<Output = Result<()>> + Send,

Consume self and start http server with provided request handler.