pub struct CipherBits {
pub secret: i32,
pub algorithm: i32,
}Available on crate feature
tls only.Expand description
Information about the state of a cipher.
Fields
secret: i32The number of secret bits used for the cipher.
algorithm: i32The number of bits processed by the chosen algorithm.