pub struct ErrorCode(/* private fields */);Available on crate feature
tls only.Expand description
SSL_ERROR_* error code returned from SSL functions.
This is different than packed error codes.
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub const ZERO_RETURN: ErrorCode
pub const ZERO_RETURN: ErrorCode
The SSL session has been closed.
Sourcepub const WANT_READ: ErrorCode
pub const WANT_READ: ErrorCode
An attempt to read data from the underlying socket returned WouldBlock.
Wait for read readiness and retry the operation.
Sourcepub const WANT_WRITE: ErrorCode
pub const WANT_WRITE: ErrorCode
An attempt to write data to the underlying socket returned WouldBlock.
Wait for write readiness and retry the operation.
pub const WANT_X509_LOOKUP: ErrorCode
pub const PENDING_SESSION: ErrorCode
pub const PENDING_CERTIFICATE: ErrorCode
pub const WANT_CERTIFICATE_VERIFY: ErrorCode
pub const WANT_PRIVATE_KEY_OPERATION: ErrorCode
pub const PENDING_TICKET: ErrorCode
Sourcepub fn from_raw(raw: i32) -> ErrorCode
pub fn from_raw(raw: i32) -> ErrorCode
Wrap an SSL_ERROR_* error code.
This is different than packed error codes.
Sourcepub fn as_raw(&self) -> i32
pub fn as_raw(&self) -> i32
An SSL_ERROR_* error code.
This is different than packed error codes.
Sourcepub fn description(self) -> Option<&'static str>
pub fn description(self) -> Option<&'static str>
This corresponds to SSL_error_description.