pub struct SelectCertError(/* private fields */);Available on crate feature
tls only.Expand description
An error returned from a certificate selection callback.
Implementations
Sourceimpl SelectCertError
impl SelectCertError
Sourcepub const ERROR: SelectCertError
pub const ERROR: SelectCertError
A fatal error occurred and the handshake should be terminated.
Sourcepub const RETRY: SelectCertError
pub const RETRY: SelectCertError
The operation could not be completed and should be retried later.