pub struct PathInfo {
pub from: SocketAddr,
pub to: SocketAddr,
}Available on crate feature
udp_group only.Expand description
Udp data transfer metadata for the data sent to the peers
from the specified local address from`` to the destination address to`.
Fields
from: SocketAddrThe specified local address.
to: SocketAddrThe destination address for the data sent to the peer.
Implementations