pub struct DefaultAsyncLockableMediator { /* private fields */ }Trait Implementations
Sourceimpl AsyncLockableMediator for DefaultAsyncLockableMediator
impl AsyncLockableMediator for DefaultAsyncLockableMediator
Sourcefn wait_lockable(&mut self, cx: &mut Context<'_>) -> usize
fn wait_lockable(&mut self, cx: &mut Context<'_>) -> usize
Available on non-crate feature
trace_lock only.Block the current task and wait for lockable event. Read more
Sourcefn cancel(&mut self, key: usize) -> bool
fn cancel(&mut self, key: usize) -> bool
Cancel the waker by key value.
Returns true if remove waker successfully.
Sourcefn notify_one(&mut self)
fn notify_one(&mut self)
Available on non-crate feature
trace_lock only.Sourcefn notify_all(&mut self)
fn notify_all(&mut self)
notify all listeners that they can try to lock this mutex again.