pub struct HttpRequestSender<T> { /* private fields */ }Available on crate feature
http_support only.Expand description
A builder to create a task to send http request.
Implementations
Sourceimpl<T> HttpRequestSender<T>
impl<T> HttpRequestSender<T>
Sourcepub fn new(request: Result<Request<T>>) -> Self
pub fn new(request: Result<Request<T>>) -> Self
Create HttpRequestSender with the default configuration other than provided Request.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set the request send / response header recv timeout. the default value is 30s.
Sourcepub fn redirect<R: ToSocketAddrs>(self, raddrs: R) -> Self
pub fn redirect<R: ToSocketAddrs>(self, raddrs: R) -> Self
Rewrite http request’s host:port fields and send request to the specified raddrs.
Sourcepub fn with_server_name(self, server_name: &str) -> Self
pub fn with_server_name(self, server_name: &str) -> Self
Set remote server’s server name, this option will rewrite request’s host field.
Sourcepub fn with_ca_file<P: AsRef<Path>>(self, ca_file: P) -> Self
pub fn with_ca_file<P: AsRef<Path>>(self, ca_file: P) -> Self
Set the server verification ca file, this is useful for self signed server.
Sourcepub async fn create(self) -> Result<(Request<T>, HttpClientWrite, Duration)>
pub async fn create(self) -> Result<(Request<T>, HttpClientWrite, Duration)>
Consume self and create new HttpClientWrite.
On success, The response wait timeout and the original Request are returned together.
Sourcepub async fn response(self) -> Result<Response<BodyReader<HttpClientRead>>>
pub async fn response(self) -> Result<Response<BodyReader<HttpClientRead>>>
Start a new
pub async fn stream_response( self, ) -> Result<Response<BodyReader<HttpClientRead>>>