pub struct QuicConnPool { /* private fields */ }Available on crate feature
quic only.Expand description
The quic connection pool implementation.
Implementations
Sourceimpl QuicConnPool
impl QuicConnPool
Sourcepub fn new_with<A: ToSocketAddrs>(
server_name: Option<&str>,
raddrs: A,
config: Config,
syscall: &'static dyn Network,
) -> Result<Self>
pub fn new_with<A: ToSocketAddrs>( server_name: Option<&str>, raddrs: A, config: Config, syscall: &'static dyn Network, ) -> Result<Self>
Sourcepub fn new<A: ToSocketAddrs>(
server_name: Option<&str>,
raddrs: A,
config: Config,
) -> Result<Self>
pub fn new<A: ToSocketAddrs>( server_name: Option<&str>, raddrs: A, config: Config, ) -> Result<Self>
Sourcepub async fn stream_open(&self) -> Result<QuicStream>
pub async fn stream_open(&self) -> Result<QuicStream>
Open new outbound stream.
This function will randomly select a connection from the pool and open a new outbound stream.
If necessary, a new Quic connection will be created.
If the max_conns is reached, returns the WouldBlock error.
Sourcepub fn set_max_conns(&mut self, value: usize) -> &mut Self
pub fn set_max_conns(&mut self, value: usize) -> &mut Self
Set max_conns parameter.
The default value is 100